# Data Models

## Core Models

::: bookwyrm.Text
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.Span
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.TextSpan
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.Citation
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.UsageInfo
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.FileClassification
options:
show_source: true
show_bases: true
inherited_members: true

## Request Models

::: bookwyrm.CitationRequest
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.SummarizeRequest
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.ProcessTextRequest
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.ClassifyRequest
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.PDFExtractRequest
options:
show_source: true
show_bases: true
inherited_members: true

## Response Models

::: bookwyrm.CitationResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.SummaryResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.ClassifyResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.PDFExtractResponse
options:
show_source: true
show_bases: true
inherited_members: true

## PDF Models

::: bookwyrm.PDFTextElement
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.PDFPage
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.PDFStructuredData
options:
show_source: true
show_bases: true
inherited_members: true

## Streaming Response Models

::: bookwyrm.CitationProgressUpdate
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.CitationStreamResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.CitationSummaryResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.CitationErrorResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.SummarizeProgressUpdate
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.SummarizeErrorResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.PhraseProgressUpdate
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.TextResult
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.TextSpanResult
options:
show_source: true
show_bases: true
inherited_members: true

## Union Types

::: bookwyrm.StreamingCitationResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.StreamingSummarizeResponse
options:
show_source: true
show_bases: true
inherited_members: true

::: bookwyrm.StreamingPhrasalResponse
options:
show_source: true
show_bases: true
inherited_members: true

## Enums

::: bookwyrm.ResponseFormat
options:
show_source: true
show_bases: true
inherited_members: true
